@@ -7,7 +7,7 @@ use warnings FATAL => 'all';
 use Sub::Name qw(subname);
 use Net::StackExchange2::V2::Common qw(query no_params one_param);
 
-our $VERSION = '0.01';
+our $VERSION = "0.05";
 
 sub new {
 	my ($class, $params) = @_;
@@ -34,7 +34,7 @@ __END__
 
 =head1 NAME
 
-StackExchange Search
+Net::StackExchange2::V2::Search - Search
 
 =head1 VERSION
 
